#
# spec file for package qalculate-qt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qalculate-qt
Version:        4.9.0
Release:        1.1
Summary:        Multi-purpose cross-platform desktop calculator
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://qalculate.github.io
Source0:        https://github.com/Qalculate/qalculate-qt/releases/download/v%{version}/qalculate-qt-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libnghttp2-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
# compilation fails on 5.12.x
BuildRequires:  pkgconfig(Qt5Core) >= 5.15.0
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libqalculate) >= %{version}
BuildRequires:  pkgconfig(libxml-2.0)

%description
Qalculate! is a multi-purpose cross-platform desktop calculator. It is
simple to use but provides power and versatility normally reserved for
complicated math packages, as well as useful tools for everyday needs
(such as currency conversion and percent calculation). Features include a
large library of customizable functions, unit calculations and conversion,
symbolic calculations (including integrals and equations), arbitrary
precision, uncertainty propagation, interval arithmetic, plotting, and a
user-friendly interface (QT, GTK+ and CLI).

%prep
%autosetup -p1

%build
%qmake5 PREFIX=%{_prefix}
make %{?_smp_mflags}

%install
%qmake5_install

%files
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/io.github.Qalculate.qalculate-qt.desktop
%dir %{_datadir}/icons/hicolor/16x16
%dir %{_datadir}/icons/hicolor/16x16/apps
%{_datadir}/icons/hicolor/16x16/apps/qalculate-qt.png
%dir %{_datadir}/icons/hicolor/22x22
%dir %{_datadir}/icons/hicolor/22x22/apps
%{_datadir}/icons/hicolor/22x22/apps/qalculate-qt.png
%dir %{_datadir}/icons/hicolor/32x32
%dir %{_datadir}/icons/hicolor/32x32/apps
%{_datadir}/icons/hicolor/32x32/apps/qalculate-qt.png
%dir %{_datadir}/icons/hicolor/64x64
%dir %{_datadir}/icons/hicolor/64x64/apps
%{_datadir}/icons/hicolor/64x64/apps/qalculate-qt.png
%dir %{_datadir}/icons/hicolor/128x128
%dir %{_datadir}/icons/hicolor/128x128/apps
%{_datadir}/icons/hicolor/128x128/apps/qalculate-qt.png
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/qalculate-qt.svg
%{_mandir}/man?/%{name}.?%{ext_man}
%{_datadir}/metainfo/io.github.Qalculate.qalculate-qt.metainfo.xml
%dir %{_datadir}/qalculate-qt
%dir %{_datadir}/qalculate-qt/translations
%{_datadir}/qalculate-qt/translations/qalculate-qt_ca.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_de.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_es.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_fr.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_nl.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_pt_BR.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_ru.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_sl.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_sv.qm
%{_datadir}/qalculate-qt/translations/qalculate-qt_zh_CN.qm

%changelog
* Sat May 11 2024 jun wang <jgwang@suse.com>
- Update to 4.9.0
  + Changes from 4.9.0
  * Support for specifying a fixed denominator for display of
    fractions
  * Return gcd of numerators divided by lcm of denominators in
    gcd() with non-integer rational numbers, and vice versa for
    lcm()
  * Add units for mean Gregorian and tropical years
  * Ignore underscore in number
  * Replace defunct exchange rates source and fix bitcoin
    exchange rate
  * Fix asin(x)=a, acos(x)=a, and atan(x)=a, when a contains an
    angle unit and default angle unit is set
  * Fix output of value converted to unit expression with
    numerical multiplier in denominator, e.g. "➞ L/(100 km)"
  * Fix segfault when trying to solve
    "(x*sqrt(x)-y*sqrt(y))/(sqrt(x)-sqrt(y))=x+sqrt(x*y)+y"
  * Fix parsing of case insensitive object name ending with
    Unicode character when followed by another Unicode character
    in expression, e.g. "микрометр"
  * Always add result to history (even if identical to previous)
    if expression contains a function generating a random
    number (GTK, Qt)
  * Prefer capitalized function name (over name with underscore),
    when completing function name (GTK, Qt)
  * Improve decision to (not) update calculate-as-you-type
    result when last character is an operator (GTK)
  * Add percent and permille output options in rational number
    form menu (GTK)
  * Fix keypad button (up/down) for cycling through expression
    history (GTK)
  * Restore decimal number base after closing programming
    keypad (Qt)
  * Improve appearance of conversion menu (Qt)
  * Save position of main window even if size has not changed
    from the default (Qt)
  * Fix custom middle click button action (Qt)
  * Fix immediate calculation after selecting to-conversion
    completion (Qt)
  * Add history command, listing expression history (CLI)
  * Display all exponents 0-9 using Unicode superscript
    characters if these are the only exponents in the
    expression (CLI)
  * Minor bug fixes and feature enhancements
  + Changes from 4.8.1
  * Fix besselj() and bessely()
  * Fix display of matrices and vectors with complex number
    form other than rectangular (default)
  * Fix conflict between decibel units (e.g. "0dB") and
    duodecimal 0d… syntax (now requires at least two digits)
  * Fixes for title options in plot() function
  * Add additional buttons and button menus to general
    keypad (Qt)
  * Add option to show all functions, units, and variables in
    tool button menus (Qt)
  * Add recently used objects to functions, units, and variables
    menus (Qt)
  * Add option to bypass dialog for functions in menu (Qt)
  * Add option, in context menu, to display text for tool
    buttons (Qt)
  * Open functions, units, and variables tool button menus using
    long-press or right-click (in addition to arrow button),
    and add keyboard shortcuts (Qt)
  * Use keypad tool button menu as context menu and show keypad
    type in title bar of keypad (Qt)
  * Auto-update number bases above programming keypad when
    entering simple integers, even if calculate-as-you-type is
    deactivated (GTK)
  + Changes from 4.8.0
  * Concise (e.g. "1.2345(67)") and relative (e.g. "5+/-2%%")
    notation for output and input (disabled by default for
    concise notation) of interval
  * Optimize rest of unit expression when converting to partial
    (insufficient) expression (e.g. 18MA×100ns to J = 1.8 J/V)
  * Round high precision intervals enclosing integers for
    integer arguments
  * Add support for specifying position of sign bit in floating
    point functions
  * New derived units: Debye, C·m, Daraf, F^-1, V/C, N/C, kcal,
    kcal/g, kJ
  * Use international foot as base unit for rod
  * Fix fibonacci() for non-integers and recursive use
  * Fix conversion options presented for speed units
    (and possibly other)
  * Update dialogs for editing of variables, functions, units,
    etc. to match the corresponding dialogs in the Qt UI (GTK)
  * Show user-defined objects in a separate category in menus
    and dialogs (GTK)
  * Add option to disable tooltips in keypad or everywhere
    (GTK, Qt)
  * Add option to disable units and to interpret unrecognized
    symbols as variables (unknowns) to preferences (Qt)
  * Make closing of application with Escape key optional and
    disabled by default (GTK, Qt)
  * Hide name column in conversion list when applied to current
    result (Qt)
  * Add temporary option to unknown variable edit dialog
    (GTK, Qt)
  * Add Microship (PIC16/17) 24 and 32 bit floating point
    formats (GTK, Qt)
  * Fix initial height of list and description in units window
    (GTK)
  * Minor bug fixes and feature enhancements
  + Changes from 4.7.0
  * Support for custom default angle unit, e.g. turn, arcsec,
    arcmin
  * Append default angle unit (instead of always radians) when
    converting value without unit to angle unit
  * More consistent addition and removal of angle unit from
    function arguments
  * Always interpret ./, .*, and .^ as entrywise operators if
    user intention is unclear
  * Change order of operations to place entrywise and ordinary
    operators on the same precedence level
  * Add function, kron(), for Kronecker product, and constants
    for Pauli matrices
  * Add radius to planets dataset and update other properties
  * Support replacement of unknown variables within variable
    values
  * Fix besselj(0, 0)
  * Fix incomplete calculation in tan() with try exact
    approximation
  * Fix 0/0=0 equality (do not return true) and output of 2/0
    (and similar)
  * Fixes and improvements for newtonsolve() and secantsolve()
  * Fix segfault when MathStructure is deleted after Calculator,
    and in destructor of calculated DynamicVariable
    (called from Calculator destructor)
  * Do not save mode on exit if "-defaults" command line switch
    where used (CLI)
  * Allow multiple actions for keyboard shortcuts (GTK, Qt)
  * Add toggle precision, and min, max, or min and max decimals
    to available shortcut and button actions (GTK, Qt)
  * Add option to exclude units for unformatted ASCII copy
    (GTK, Qt)
  * Add optional value to copy result action, allowing
    expression copy and formatting selection (GTK, Qt)
  * Fix copy unformatted ASCII when local digit group separator
    is same as selected decimal separator (GTK, Qt)
  * Add option to automatically copy result (Qt)
  * Always set (primary) selection clipboard contents when whole
    expression is selected or selection is cleared, e.g. after
    calculation (Qt)
  * Improve support dark mode and high contrast modes, and
    change default style to Fusion, on Windows (Qt)
  * Minor bug fixes and feature enhancements
* Thu Apr 20 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.6.1:
  * More robust and consistent default language detection and option
    to change language on Windows
  * Option to change symbols used for output of digits 10 and 11 in
    duodecimal numbers (use A and B as default digits)
* Tue Dec 27 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.0:
  * Use history font for RPN stack list (GTK, Qt)
  * Use log() instead of log2() as alternative action on "ln" keypad button (Qt)
  * Fix completion (including segfaults) and expression tooltip on Wayland (Qt)
  * Fix RPN mode deactivated after application loses focus (Qt)
* Fri Nov 11 2022 Paolo Stivanin <info@paolostivanin.com>
- Fix spec file, update QT min version.
* Thu Nov 10 2022 Paolo Stivanin <info@paolostivanin.com>
- Initial OBS release.
